==> ejc-assistrmat-impl-3.0.0-20220609.043105-148-sources.jar: com/ejianc/business/common/CommonConstant.java <==
package com.ejianc.business.common;

import java.util.HashMap;
import java.util.Map;

public class CommonConstant {

    public static final Integer YES_INT = 1; // 公用"是"
    public static final Integer NO_INT = 0; // 公用"否"

    public static final String YES_STR = "1"; // 公用"是"
    public static final String NO_STR = "0"; // 公用"否"


    public static final String ORDER_RECEIVE_WAIT = "0"; //待接收
    public static final String ORDER_RECEIVE_ALL = "1"; //全部接收
    public static final String ORDER_RECEIVE_PART = "2"; //部分接收
    public static final String ORDER_RECEIVE_NOT = "3"; //不予接收
    
    public static final Integer UN_OCCUPY_STATE = 0; // 定标结果未占用状态
    public static final Integer OCCUPY_STATE = 1; // 定标结果占用状态

    public static final String CONTRACT_REFCODE = "arri_contract"; // 辅料中心租入合同refcode
    public static final String CONTRACT_REFCODE_CHANGE = "arri_contract_change"; // 辅料中心租入合同变更refcode
    public static final String CONTRACT_RECORD_REFCODE = "arri_contract_record"; // 辅料中心租入合同记录refcode
    public static final String CONTRACT_RECORD_RELIEVE = "arri_contract_relieve"; // 辅料中心租入合同解除refcode
    
    public static final String CONTRACT_FILE_SOURCE_TYPE = "arriContractFile"; // 辅料中心租入合同附件业务类型
    public static final String CONTRACT_ATTACH_SOURCE_TYPE = "arriContract"; // 辅料中心租入合同附件管理业务类型

    public static final String CONTRACT_CHANGE_FILE_SOURCE_TYPE = "arriContractChangeFile"; // 辅料中心租入合同变更附件业务类型
    public static final String CONTRACT_CHANGE_ATTACH_SOURCE_TYPE = "arriContractChange"; // 辅料中心租入合同变更附件管理业务类型

    public static final String CONTRACT_RECORD_FILE_SOURCE_TYPE = "arriContractRecordFile"; // 辅料中心租入合同记录附件业务类型
    public static final String CONTRACT_RECORD_ATTACH_SOURCE_TYPE = "arriContractRecord"; // 辅料中心租入合同记录附件管理业务类型
    
    
    public static final Map<String,String> ORDER_RECEIVE_STATE = new HashMap(); //接收状态（0-待接收，1-全部接收，2-部分接受，3-不予接收）

    static {
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_WAIT,"待接收");
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_ALL,"全部接收");
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_PART,"部分接受");
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_NOT,"不予接收");
    }


    public static final String ORDER_DELIVER_WAIT = "1"; //待送货
    public static final String ORDER_DELIVER_ALL = "2"; //全部送货
    public static final String ORDER_DELIVER_PART = "3"; //部分送货

    public static final Map<String,String> ORDER_DELIVER_STATE = new HashMap(); //送货状态（1-待送货，2-全部送货，3-部分送货）

    static {
        ORDER_DELIVER_STATE.put(ORDER_DELIVER_WAIT,"待送货");
        ORDER_DELIVER_STATE.put(ORDER_DELIVER_ALL,"全部送货");
        ORDER_DELIVER_STATE.put(ORDER_DELIVER_PART,"部分送货");
    }

    public static final String ORDER_DISABLE_YES = "1"; //是
    public static final String ORDER_DISABLE_NO = "0"; //否

    public static final Map<String,String> ORDER_DISABLE_STATE = new HashMap(); //关闭状态（1-是，0-否）

    static {
        ORDER_DISABLE_STATE.put(ORDER_DISABLE_YES,"是");
        ORDER_DISABLE_STATE.put(ORDER_DISABLE_NO,"否");
    }


    public static final String CONTRACT_RENT_CALCULATION_TYPE_DAILY = "0"; //日租
    public static final String CONTRACT_RENT_CALCULATION_TYPE_MONTH = "1"; //月租
    public static final String CONTRACT_RENT_CALCULATION_TYPE_NUM = "2"; //工程量租

    public static final Map<String,String> CONTRACT_RENT_CALCULATION_TYPE = new HashMap(); //合同租赁方式(0-日租，1-月租，2-工程量租)

    static {
        CONTRACT_RENT_CALCULATION_TYPE.put(CONTRACT_RENT_CALCULATION_TYPE_DAILY,"日租");
        CONTRACT_RENT_CALCULATION_TYPE.put(CONTRACT_RENT_CALCULATION_TYPE_MONTH,"月租");
        CONTRACT_RENT_CALCULATION_TYPE.put(CONTRACT_RENT_CALCULATION_TYPE_NUM,"工程量租");
    }

    public static final String DELIVERY_ACCEPTANCE_WAIT = "0"; //待验收
    public static final String DELIVERY_ACCEPTANCE_PART = "1"; //部分验收
    public static final String DELIVERY_ACCEPTANCE_ALL = "2"; //全部验收

    public static final Map<String,String> DELIVERY_ACCEPTANCE_MAP = new HashMap(); //送货单验收状态(0-待验收，1-部分验收，2-全部验收)

    static {
        DELIVERY_ACCEPTANCE_MAP.put(DELIVERY_ACCEPTANCE_WAIT,"待验收");
        DELIVERY_ACCEPTANCE_MAP.put(DELIVERY_ACCEPTANCE_PART,"部分验收");
        DELIVERY_ACCEPTANCE_MAP.put(DELIVERY_ACCEPTANCE_ALL,"全部验收");
    }


    public static final String CHECK_SOURCE_ZZ = "0"; //自制
    public static final String CHECK_SOURCE_YS = "1"; //验收

    public static final String CHECK_TYPE_SLRK = "0"; //收料入库
    public static final String CHECK_TYPE_ZRZC = "1"; //直入直出


}

==> ejc-assistrmat-impl-3.0.0-20220930.070234-246-sources.jar: com/ejianc/business/common/CommonConstant.java <==
package com.ejianc.business.common;

import java.util.HashMap;
import java.util.Map;

public class CommonConstant {

    public static final Integer YES_INT = 1; // 公用"是"
    public static final Integer NO_INT = 0; // 公用"否"

    public static final String YES_STR = "1"; // 公用"是"
    public static final String NO_STR = "0"; // 公用"否"


    public static final String ORDER_RECEIVE_WAIT = "0"; //待接收
    public static final String ORDER_RECEIVE_ALL = "1"; //全部接收
    public static final String ORDER_RECEIVE_PART = "2"; //部分接收
    public static final String ORDER_RECEIVE_NOT = "3"; //不予接收
    
    public static final Integer UN_OCCUPY_STATE = 0; // 定标结果未占用状态
    public static final Integer OCCUPY_STATE = 1; // 定标结果占用状态

    public static final String CONTRACT_REFCODE = "arri_contract"; // 辅料中心租入合同refcode
    public static final String CONTRACT_REFCODE_CHANGE = "arri_contract_change"; // 辅料中心租入合同变更refcode
    public static final String CONTRACT_RECORD_REFCODE = "arri_contract_record"; // 辅料中心租入合同记录refcode
    public static final String CONTRACT_RECORD_RELIEVE = "arri_contract_relieve"; // 辅料中心租入合同解除refcode

    public static final String OUT_RMAT_CONTRACT_REFCODE = "out_arri_contract"; // 辅料中心租出合同refcode
    public static final String OUT_RMAT_CONTRACT_REFCODE_CHANGE = "out_arri_contract_change"; // 辅料中心租出合同变更refcode
    public static final String OUT_RMAT_CONTRACT_RECORD_REFCODE = "out_arri_contract_record"; // 辅料中心租出合同记录refcode
    public static final String OUT_RMAT_CONTRACT_RECORD_RELIEVE = "out_arri_contract_relieve"; // 辅料中心租出合同解除refcode
    
    public static final String CONTRACT_FILE_SOURCE_TYPE = "arriContractFile"; // 辅料中心租入合同附件业务类型
    public static final String CONTRACT_ATTACH_SOURCE_TYPE = "arriContract"; // 辅料中心租入合同附件管理业务类型

    public static final String CONTRACT_CHANGE_FILE_SOURCE_TYPE = "arriContractChangeFile"; // 辅料中心租入合同变更附件业务类型
    public static final String CONTRACT_CHANGE_ATTACH_SOURCE_TYPE = "arriContractChange"; // 辅料中心租入合同变更附件管理业务类型

    public static final String CONTRACT_RECORD_FILE_SOURCE_TYPE = "arriContractRecordFile"; // 辅料中心租入合同记录附件业务类型
    public static final String CONTRACT_RECORD_ATTACH_SOURCE_TYPE = "arriContractRecord"; // 辅料中心租入合同记录附件管理业务类型
    
    
    public static final Map<String,String> ORDER_RECEIVE_STATE = new HashMap(); //接收状态（0-待接收，1-全部接收，2-部分接受，3-不予接收）

    static {
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_WAIT,"待接收");
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_ALL,"全部接收");
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_PART,"部分接受");
        ORDER_RECEIVE_STATE.put(ORDER_RECEIVE_NOT,"不予接收");
    }


    public static final String ORDER_DELIVER_WAIT = "1"; //待送货
    public static final String ORDER_DELIVER_ALL = "2"; //全部送货
    public static final String ORDER_DELIVER_PART = "3"; //部分送货

    public static final Map<String,String> ORDER_DELIVER_STATE = new HashMap(); //送货状态（1-待送货，2-全部送货，3-部分送货）

    static {
        ORDER_DELIVER_STATE.put(ORDER_DELIVER_WAIT,"待送货");
        ORDER_DELIVER_STATE.put(ORDER_DELIVER_ALL,"全部送货");
        ORDER_DELIVER_STATE.put(ORDER_DELIVER_PART,"部分送货");
    }

    public static final String ORDER_DISABLE_YES = "1"; //是
    public static final String ORDER_DISABLE_NO = "0"; //否

    public static final Map<String,String> ORDER_DISABLE_STATE = new HashMap(); //关闭状态（1-是，0-否）

    static {
        ORDER_DISABLE_STATE.put(ORDER_DISABLE_YES,"是");
        ORDER_DISABLE_STATE.put(ORDER_DISABLE_NO,"否");
    }


    public static final String CONTRACT_RENT_CALCULATION_TYPE_DAILY = "0"; //日租
    public static final String CONTRACT_RENT_CALCULATION_TYPE_MONTH = "1"; //月租
    public static final String CONTRACT_RENT_CALCULATION_TYPE_NUM = "2"; //工程量租

    public static final Map<String,String> CONTRACT_RENT_CALCULATION_TYPE = new HashMap(); //合同租赁方式(0-日租，1-月租，2-工程量租)

    static {
        CONTRACT_RENT_CALCULATION_TYPE.put(CONTRACT_RENT_CALCULATION_TYPE_DAILY,"日租");
        CONTRACT_RENT_CALCULATION_TYPE.put(CONTRACT_RENT_CALCULATION_TYPE_MONTH,"月租");
        CONTRACT_RENT_CALCULATION_TYPE.put(CONTRACT_RENT_CALCULATION_TYPE_NUM,"工程量租");
    }

    public static final String DELIVERY_ACCEPTANCE_WAIT = "0"; //待验收
    public static final String DELIVERY_ACCEPTANCE_PART = "1"; //部分验收
    public static final String DELIVERY_ACCEPTANCE_ALL = "2"; //全部验收

    public static final Map<String,String> DELIVERY_ACCEPTANCE_MAP = new HashMap(); //送货单验收状态(0-待验收，1-部分验收，2-全部验收)

    static {
        DELIVERY_ACCEPTANCE_MAP.put(DELIVERY_ACCEPTANCE_WAIT,"待验收");
        DELIVERY_ACCEPTANCE_MAP.put(DELIVERY_ACCEPTANCE_PART,"部分验收");
        DELIVERY_ACCEPTANCE_MAP.put(DELIVERY_ACCEPTANCE_ALL,"全部验收");
    }


    public static final String CHECK_SOURCE_ZZ = "0"; //自制
    public static final String CHECK_SOURCE_YS = "1"; //验收

    public static final String CHECK_TYPE_SLRK = "0"; //收料入库
    public static final String CHECK_TYPE_ZRZC = "1"; //直入直出


}
